summaryrefslogtreecommitdiffstats
path: root/noatun/library/noatun/pref.h
diff options
context:
space:
mode:
Diffstat (limited to 'noatun/library/noatun/pref.h')
-rw-r--r--noatun/library/noatun/pref.h8
1 files changed, 5 insertions, 3 deletions
diff --git a/noatun/library/noatun/pref.h b/noatun/library/noatun/pref.h
index 5a7d056e..a290e51c 100644
--- a/noatun/library/noatun/pref.h
+++ b/noatun/library/noatun/pref.h
@@ -13,6 +13,7 @@ class CModule;
class NoatunPreferences : public KDialogBase
{
Q_OBJECT
+ TQ_OBJECT
friend class CModule;
public:
@@ -53,19 +54,20 @@ private:
* Create your GUI in constructor, reimplement reopen() and save() and
* you're all set.
**/
-class KDE_EXPORT CModule : public QWidget
+class KDE_EXPORT CModule : public TQWidget
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* arguments are short and long descriptions
* for this module, respectively
*
* parent is the object that is this modules virtual-parent.
* When that is deleted, this also will go away, automagically.
**/
- CModule(const TQString &name, const TQString &description, const TQString &icon, TQObject *parent=0);
+ CModule(const TQString &name, const TQString &description, const TQString &icon, TQObject *tqparent=0);
virtual ~CModule();
@@ -53,19 +54,20 @@ private:
* for this module, respectively
*
- * parent is the object that is this modules virtual-parent.
+ * tqparent is the object that is this modules virtual-tqparent.
* When that is deleted, this also will go away, automagically.
**/